import { ThumbsOptions } from 'swiper/types/modules/thumbs';
import { AutoplayOptions } from 'swiper/types/modules/autoplay';
import { NavigationOptions } from 'swiper/types/modules/navigation';
import { PaginationOptions } from 'swiper/types/modules/pagination';
import { ProductConfiguration } from '@crystaldesign/basket-model';
export type ContentBoxProps = GalleryProductProps | MediaViewerProps | ArViewerProps | CloseButtonContainerProps | SliderContainerProps | ImageProps | InfoBoxProps | VariantFieldsProps | OverlayProps | TextProps | ContentListProps | PDFProps | TranslationProps;
interface BaseProps {
    parameters?: {
        [key: string]: string;
    };
}
export interface GalleryProductProps extends BaseProps {
    type: 'ProductGallery';
    products: Product[];
    groupVariantsByField?: string[];
    onClick: (productId: string) => void;
    imageWrapperStyle?: React.CSSProperties;
    imageStyle?: React.CSSProperties;
    textStyle?: React.CSSProperties;
    wrapperStyle?: React.CSSProperties;
    hidePrices?: boolean;
}
export interface VariantFieldsProps extends BaseProps {
    type: 'VariantFields';
    variants: Product[];
    groupVariantsByField?: string[];
    currentProuduct: Product;
    setCurProduct: (e: any, product: Product, variants?: Product[]) => void;
    inSlider?: SliderContainerProps;
    style?: 'horizontal';
}
export interface MediaViewerProps extends BaseProps {
    type: 'MediaViewer';
    medias?: Media[];
    mediaIds?: string[];
    itemKey?: string;
    defaultDataOptions?: string;
    onLandscapeOptions?: string;
    showRotationIconInFullscreen?: boolean;
    currentItem?: number;
    setCurrentItem?: (item: number) => void;
    keepOldZoomIcons?: boolean;
}
export interface Media {
    _id?: string;
    url: string;
    borderPercentage?: number;
    class?: string;
    name?: string;
    shortUrl?: string;
    description?: string;
    position?: number;
    thumb?: JSX.Element | string;
    functionType?: 'SHO' | 'OPV' | 'ART' | '2D' | 'PROD';
    mediaType?: 'PCT' | 'PDF' | 'AR' | 'SPIN' | 'VIDEO' | 'SPN' | 'VID';
    storage?: 'SIRV' | 'BLOB' | 'IO' | 'MAM' | 'OTHER';
    qrCodeUrl?: string;
    arViewerSettings?: {
        name: string;
        environmentImage: 'neutral' | 'default';
        exposure: number;
        useEnvironmentasSkybox: boolean;
        shadowIntensity: number;
        shadowSoftness: number;
    }[];
}
export interface ArViewerProps extends BaseProps {
    type: 'ArViewer';
    url: string;
    qrCodeUrl?: string;
    cameraArButton?: boolean;
    viewerClassName?: string;
    isCurrentlyVisible?: boolean;
    arViewerSettings?: {
        name: string;
        environmentImage: 'neutral' | 'default';
        exposure: number;
        useEnvironmentasSkybox: boolean;
        shadowIntensity: number;
        shadowSoftness: number;
    }[];
}
export interface CloseButtonContainerProps extends BaseProps {
    type: 'CloseButtonContainer';
    content: ContentBoxProps | JSX.Element;
    style?: React.CSSProperties;
    closeIconSize?: string;
    hideCloseIconInPortrait?: boolean;
    switchCloseIconToLeftInPortrait?: boolean;
    hideCloseIcon?: boolean;
}
export interface ImageProps extends BaseProps {
    type: 'Image';
    url: string;
    cover?: boolean;
    style?: React.CSSProperties;
}
export interface OverlayProps extends BaseProps {
    type: 'Overlay';
    style?: React.CSSProperties;
    content: ContentBoxProps;
    background?: ContentBoxProps;
}
export interface ContentListProps extends BaseProps {
    type: 'ContentList';
    style?: React.CSSProperties;
    contents: ContentBoxProps[];
}
export interface TextProps extends BaseProps {
    type: 'Text';
    style?: React.CSSProperties;
    text: string;
}
export interface TranslationProps extends BaseProps {
    type: 'Translation';
    translation: {
        [languageKey: string]: ContentBoxProps;
    };
}
export interface PDFProps extends BaseProps {
    type: 'PDF';
    url: string;
    description?: string;
    style?: React.CSSProperties;
    openInNewTab?: boolean;
    iconsize?: string;
}
export interface SliderContainerProps extends BaseProps {
    type: 'SliderContainer';
    contents: Content[];
    sliderType: 'scrollY' | 'slideY' | 'scrollX' | 'slideX' | 'Tabs';
    autoPlay?: AutoplayOptions | number;
    loop?: boolean;
    pagination?: PaginationOptions | boolean;
    navigation?: NavigationOptions | boolean;
    height?: 'auto';
    autoHeight?: boolean;
    watchSlidesProgress?: boolean;
    slidesPerView?: number | 'auto';
    allowSlideNext?: boolean;
    allowSlidePrev?: boolean;
    allowTouchMove?: boolean;
    resistanceRatio?: number;
    centeredSlides?: boolean;
    wrapperClass?: string;
    thumbs?: ThumbsOptions;
    onSwiper?: any;
    freeMode?: boolean;
    mousewheel?: boolean;
    spaceBetween?: number;
    scrollToSelectedItem?: boolean;
    swipeRef?: [any | null, React.Dispatch<React.SetStateAction<any | null>>];
    on?: {
        slideChange?: ((swiper: any) => void) | undefined;
    };
}
export interface Content {
    title?: JSX.Element | string;
    content: ContentBoxProps | JSX.Element;
    swiperSlideStyle?: React.CSSProperties;
}
export interface InfoBoxProps extends BaseProps {
    type: 'InfoBox';
    title: string;
    imageUrl?: string;
    price?: number;
    text?: string;
}
export type Langs = 'DE' | 'FR' | 'IT' | 'EN';
export interface Product {
    addedPrice: number;
    discountedPrice: number;
    articles: {
        articleCodex: string;
        catalogCodex: string;
        variantValues: {
            OPT: string;
            OPV: string;
        }[];
    }[];
    divaNr: string;
    image: string;
    image2D: string;
    shortDescription: string;
    configuration?: ProductConfiguration;
    _id: string;
    width?: number;
    height?: number;
    depth?: number;
    media?: Media[];
    technicalDescription?: string;
    shortTechnicalDescription?: string;
    orderDescription?: string;
    info?: string;
    parent?: string;
    variantId?: number;
    originDivaNr?: string;
    modelName?: string;
    livingArea?: string;
    mainCategory?: string;
    startProductForOrganizations?: string[];
    catCodex: string[];
    supplierId?: string[];
    state?: number;
    stateHistory?: StateHistory[];
}
export interface StateHistory {
    state: number;
    author: string;
    authorByName?: string;
    authorByEmail?: string;
    created: number;
    message?: string;
}
export type TabType = 'cp' | 'cp1' | 'cp2' | 'info' | 'tech' | 'functions';
export interface Variant {
    variantId: number;
    image?: string;
    colums: VariantRow[];
}
export interface VariantRow {
    opt: string;
    optName: string;
    opv: string;
    name: string;
    image?: string;
}
export {};
//# sourceMappingURL=index.d.ts.map